Evolution Strategies (ES)
=========================

.. autoclass:: pypop7.optimizers.es.es.ES



.. toctree::
   :maxdepth: 2
   :caption: ESs:

   lmcma
   mmes
   fcmaes
   ddcma
   lmmaes
   rmes
   r1es
   vkdcma
   vdcma
   lmcmaes
   fmaes
   maes
   ccmaes2016
   opoa2015
   opoa2010
   ccmaes2009
   opoc2009
   sepcmaes
   opoc2006
   cmaes
   samaes
   saes
   csaes
   dsaes
   ssaes
   res
